@@ -3,6 +3,7 @@
  * Copyright © 2015 Alessandro Bono
  * Copyright © 2014 – 2015 Pranav Kant
  * Copyright © 2012 – 2017 Red Hat, Inc.
+ * Copyright © 2016 Umang Jain
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -82,7 +83,7 @@ struct _PhotosApplication
   GSettings *bg_settings;
   GSettings *ss_settings;
   GSimpleAction *blacks_exposure_action;
-  GSimpleAction *brightness_contrast_action;
+  GSimpleAction *contrast_action;
   GSimpleAction *crop_action;
   GSimpleAction *delete_action;
   GSimpleAction *denoise_action;
@@ -109,6 +110,7 @@ struct _PhotosApplication
   GSimpleAction *selection_mode_action;
   GSimpleAction *set_bg_action;
   GSimpleAction *set_ss_action;
+  GSimpleAction *shadows_highlights_action;
   GSimpleAction *share_action;
   GSimpleAction *sharpen_action;
   GSimpleAction *zoom_begin_action;
@@ -124,6 +126,7 @@ struct _PhotosApplication
   PhotosSelectionController *sel_cntrlr;
   PhotosThumbnailFactory *factory;
   TrackerExtractPriority *extract_priority;
+  gboolean empty_results;
   gboolean main_window_deleted;
   guint create_miners_count;
   guint init_fishes_id;
@@ -156,33 +159,11 @@ enum
 
 static const GOptionEntry COMMAND_LINE_OPTIONS[] =
 {
+  { "empty-results", 0, G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE, NULL, N_("Show the empty state"), NULL },
   { "version", 0, G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE, NULL, N_("Show the application's version"), NULL},
   { NULL }
 };
 
-static const gchar *REQUIRED_GEGL_OPS[] =
-{
-  "gegl:buffer-sink",
-  "gegl:buffer-source",
-  "gegl:crop",
-  "gegl:exposure",
-  "gegl:gray",
-  "gegl:load",
-  "gegl:noise-reduction",
-  "gegl:nop",
-  "gegl:pixbuf",
-  "gegl:rotate-on-center",
-  "gegl:save-pixbuf",
-  "gegl:scale-ratio",
-  "gegl:unsharp-mask",
-
-  /* Used by gegl:load */
-  "gegl:jpg-load",
-  "gegl:png-load",
-  "gegl:raw-load",
-  "gegl:text"
-};
-
 static const gchar *DESKTOP_BACKGROUND_SCHEMA = "org.gnome.desktop.background";
 static const gchar *DESKTOP_SCREENSAVER_SCHEMA = "org.gnome.desktop.screensaver";
 static const gchar *DESKTOP_KEY_PICTURE_URI = "picture-uri";
@@ -382,13 +363,14 @@ photos_application_actions_update (PhotosApplication *self)
 
   enable = (mode == PHOTOS_WINDOW_MODE_EDIT);
   g_simple_action_set_enabled (self->blacks_exposure_action, enable);
-  g_simple_action_set_enabled (self->brightness_contrast_action, enable);
+  g_simple_action_set_enabled (self->contrast_action, enable);
   g_simple_action_set_enabled (self->crop_action, enable);
   g_simple_action_set_enabled (self->denoise_action, enable);
   g_simple_action_set_enabled (self->edit_cancel_action, enable);
   g_simple_action_set_enabled (self->edit_done_action, enable);
   g_simple_action_set_enabled (self->insta_action, enable);
   g_simple_action_set_enabled (self->saturation_action, enable);
+  g_simple_action_set_enabled (self->shadows_highlights_action, enable);
   g_simple_action_set_enabled (self->sharpen_action, enable);
 
   enable = FALSE;
@@ -632,32 +614,6 @@ photos_application_gegl_init_fishes_idle (gpointer user_data)
 }
 
 
-static gboolean
-photos_application_sanity_check_gegl (PhotosApplication *self)
-{
-  GeglConfig *config;
-  gboolean ret_val = TRUE;
-  gboolean use_opencl;
-  guint i;
-
-  config = gegl_config ();
-  g_object_get (config, "use-opencl", &use_opencl, NULL);
-  photos_debug (PHOTOS_DEBUG_GEGL, "Using OpenCL: %s", use_opencl ? "yes" : "no");
-
-  for (i = 0; i < G_N_ELEMENTS (REQUIRED_GEGL_OPS); i++)
-    {
-      if (!gegl_has_operation (REQUIRED_GEGL_OPS[i]))
-        {
-          g_warning ("Unable to find GEGL operation %s: Check your GEGL install", REQUIRED_GEGL_OPS[i]);
-          ret_val = FALSE;
-          break;
-        }
-    }
-
-  return ret_val;
-}
-
-
 static void
 photos_application_tracker_set_rdf_types (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
@@ -711,22 +667,22 @@ photos_application_tracker_extract_priority (GObject *source_object, GAsyncResul
 static gboolean
 photos_application_create_window (PhotosApplication *self)
 {
+  gboolean gegl_sanity_checked;
   gboolean gexiv2_initialized;
   gboolean gexiv2_registered_namespace;
-  gboolean sanity_checked_gegl;
 
   if (self->main_window != NULL)
     return TRUE;
 
+  gegl_sanity_checked = photos_gegl_sanity_check ();
+  g_return_val_if_fail (gegl_sanity_checked, FALSE);
+
   gexiv2_initialized = gexiv2_initialize ();
   g_return_val_if_fail (gexiv2_initialized, FALSE);
 
   gexiv2_registered_namespace = gexiv2_metadata_register_xmp_namespace ("http://www.gnome.org/xmp", "gnome");
   g_return_val_if_fail (gexiv2_registered_namespace, FALSE);
 
-  sanity_checked_gegl = photos_application_sanity_check_gegl (self);
-  g_return_val_if_fail (sanity_checked_gegl, FALSE);
-
   self->main_window = photos_main_window_new (GTK_APPLICATION (self));
   g_signal_connect_object (self->main_window,
                            "delete-event",
@@ -1717,6 +1673,34 @@ photos_application_activate (GApplication *application)
 }
 
 
+static gint
+photos_application_command_line (GApplication *application, GApplicationCommandLine *command_line)
+{
+  PhotosApplication *self = PHOTOS_APPLICATION (application);
+  GVariantDict *options;
+  gint ret_val = -1;
+
+  photos_debug (PHOTOS_DEBUG_APPLICATION, "PhotosApplication::command_line");
+
+  options = g_application_command_line_get_options_dict (command_line);
+  if (g_variant_dict_contains (options, "empty-results"))
+    {
+      if (g_application_command_line_get_is_remote (command_line))
+        {
+          ret_val = EXIT_FAILURE;
+          goto out;
+        }
+
+      self->empty_results = TRUE;
+    }
+
+  g_application_activate (application);
+
+ out:
+  return ret_val;
+}
+
+
 static gboolean
 photos_application_dbus_register (GApplication *application,
                                   GDBusConnection *connection,
@@ -1852,7 +1836,6 @@ photos_application_startup (GApplication *application)
   GtkIconTheme *icon_theme;
   GtkSettings *settings;
   GVariant *state;
-  GVariantType *parameter_type;
   const gchar *delete_accels[3] = {"Delete", "KP_Delete", NULL};
   const gchar *edit_accels[2] = {"<Primary>e", NULL};
   const gchar *fullscreen_accels[2] = {"F11", NULL};
@@ -1872,7 +1855,7 @@ photos_application_startup (GApplication *application)
 
   G_APPLICATION_CLASS (photos_application_parent_class)->startup (application);
 
-  gegl_init (NULL, NULL);
+  photos_gegl_init ();
 
   grl_init (NULL, NULL);
   registry = grl_registry_get_default ();
@@ -1931,20 +1914,14 @@ photos_application_startup (GApplication *application)
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (action));
   g_object_unref (action);
 
-  parameter_type = g_variant_type_new ("a{sd}");
-  self->blacks_exposure_action = g_simple_action_new ("blacks-exposure-current", parameter_type);
+  self->blacks_exposure_action = g_simple_action_new ("blacks-exposure-current", G_VARIANT_TYPE ("a{sd}"));
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (self->blacks_exposure_action));
-  g_variant_type_free (parameter_type);
 
-  parameter_type = g_variant_type_new ("a{sd}");
-  self->brightness_contrast_action = g_simple_action_new ("brightness-contrast-current", parameter_type);
-  g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (self->brightness_contrast_action));
-  g_variant_type_free (parameter_type);
+  self->contrast_action = g_simple_action_new ("contrast-current", G_VARIANT_TYPE_DOUBLE);
+  g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (self->contrast_action));
 
-  parameter_type = g_variant_type_new ("a{sd}");
-  self->crop_action = g_simple_action_new ("crop-current", parameter_type);
+  self->crop_action = g_simple_action_new ("crop-current", G_VARIANT_TYPE ("a{sd}"));
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (self->crop_action));
-  g_variant_type_free (parameter_type);
 
   self->delete_action = g_simple_action_new ("delete", NULL);
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (self->delete_action));
@@ -2066,6 +2043,9 @@ photos_application_startup (GApplication *application)
   g_signal_connect_swapped (self->set_ss_action, "activate", G_CALLBACK (photos_application_set_screensaver), self);
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (self->set_ss_action));
 
+  self->shadows_highlights_action = g_simple_action_new ("shadows-highlights-current", G_VARIANT_TYPE ("a{sd}"));
+  g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (self->shadows_highlights_action));
+
   self->share_action = g_simple_action_new ("share-current", NULL);
   g_signal_connect_swapped (self->share_action, "activate", G_CALLBACK (photos_application_share_current), self);
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (self->share_action));
@@ -2172,7 +2152,7 @@ photos_application_dispose (GObject *object)
   g_clear_object (&self->bg_settings);
   g_clear_object (&self->ss_settings);
   g_clear_object (&self->blacks_exposure_action);
-  g_clear_object (&self->brightness_contrast_action);
+  g_clear_object (&self->contrast_action);
   g_clear_object (&self->crop_action);
   g_clear_object (&self->delete_action);
   g_clear_object (&self->denoise_action);
@@ -2199,6 +2179,7 @@ photos_application_dispose (GObject *object)
   g_clear_object (&self->selection_mode_action);
   g_clear_object (&self->set_bg_action);
   g_clear_object (&self->set_ss_action);
+  g_clear_object (&self->shadows_highlights_action);
   g_clear_object (&self->share_action);
   g_clear_object (&self->sharpen_action);
   g_clear_object (&self->zoom_begin_action);
@@ -2245,6 +2226,7 @@ photos_application_init (PhotosApplication *self)
   self->activation_timestamp = GDK_CURRENT_TIME;
 
   g_application_add_main_option_entries (G_APPLICATION (self), COMMAND_LINE_OPTIONS);
+  g_application_set_flags (G_APPLICATION (self), G_APPLICATION_HANDLES_COMMAND_LINE);
 }
 
 
@@ -2257,6 +2239,7 @@ photos_application_class_init (PhotosApplicationClass *class)
   object_class->dispose = photos_application_dispose;
   object_class->finalize = photos_application_finalize;
   application_class->activate = photos_application_activate;
+  application_class->command_line = photos_application_command_line;
   application_class->dbus_register = photos_application_dbus_register;
   application_class->dbus_unregister = photos_application_dbus_unregister;
   application_class->handle_local_options = photos_application_handle_local_options;
@@ -2292,6 +2275,14 @@ photos_application_new (void)
 }
 
 
+gboolean
+photos_application_get_empty_results (PhotosApplication *self)
+{
+  g_return_val_if_fail (PHOTOS_IS_APPLICATION (self), FALSE);
+  return self->empty_results;
+}
+
+
 GomMiner *
 photos_application_get_miner (PhotosApplication *self, const gchar *provider_type)
 {
