@@ -23,9 +23,7 @@
 #include "config.h"
 
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
 
-#include "photos-base-item.h"
 #include "photos-done-notification.h"
 #include "photos-filterable.h"
 #include "photos-icons.h"
@@ -106,7 +104,7 @@ photos_done_notification_constructed (GObject *object)
   GtkWidget *undo;
   const gchar *id;
   const gchar *name;
-  gchar *msg;
+  g_autofree gchar *msg = NULL;
 
   G_OBJECT_CLASS (photos_done_notification_parent_class)->constructed (object);
 
@@ -120,7 +118,6 @@ photos_done_notification_constructed (GObject *object)
   gtk_widget_set_halign (label, GTK_ALIGN_START);
   gtk_widget_set_hexpand (label, TRUE);
   gtk_container_add (GTK_CONTAINER (self), label);
-  g_free (msg);
 
   undo = gtk_button_new_with_label (_("Undo"));
   gtk_widget_set_valign (undo, GTK_ALIGN_CENTER);
@@ -182,11 +179,8 @@ photos_done_notification_set_property (GObject *object, guint prop_id, const GVa
   switch (prop_id)
     {
       case PROP_ITEM:
-        {
-          PhotosBaseItem *item = (PhotosBaseItem *) g_value_get_pointer (value);
-          self->item = g_object_ref (item);
-          break;
-        }
+        self->item = PHOTOS_BASE_ITEM (g_value_dup_object (value));
+        break;
 
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -218,10 +212,11 @@ photos_done_notification_class_init (PhotosDoneNotificationClass *class)
 
   g_object_class_install_property (object_class,
                                    PROP_ITEM,
-                                   g_param_spec_pointer ("item",
-                                                         "PhotosBaseItem instance",
-                                                         "The edited PhotosBaseItem",
-                                                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+                                   g_param_spec_object ("item",
+                                                        "PhotosBaseItem instance",
+                                                        "The edited PhotosBaseItem",
+                                                        PHOTOS_TYPE_BASE_ITEM,
+                                                        G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
 }
 
 
