@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2016 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,11 +37,6 @@ struct _PhotosOrganizeCollectionDialog
   GtkWidget *coll_view;
 };
 
-struct _PhotosOrganizeCollectionDialogClass
-{
-  GtkDialogClass parent_class;
-};
-
 
 G_DEFINE_TYPE (PhotosOrganizeCollectionDialog, photos_organize_collection_dialog, GTK_TYPE_DIALOG);
 
