@@ -262,8 +262,6 @@ photos_preview_view_gesture_zoom_begin (PhotosPreviewView *self)
   gtk_gesture_set_state (gesture_zoom, GTK_EVENT_SEQUENCE_CLAIMED);
 
   parameter = photos_utils_create_zoom_target_value (0.0, PHOTOS_ZOOM_EVENT_TOUCH);
-  g_assert_true (g_variant_is_floating (parameter));
-
   g_action_activate (self->zoom_begin_action, parameter);
 }
 
@@ -274,13 +272,9 @@ photos_preview_view_gesture_zoom_direction_changed (PhotosPreviewView *self)
   GVariant *parameter;
 
   parameter = photos_utils_create_zoom_target_value (0.0, PHOTOS_ZOOM_EVENT_TOUCH);
-  g_assert_true (g_variant_is_floating (parameter));
-
   g_action_activate (self->zoom_end_action, parameter);
 
   parameter = photos_utils_create_zoom_target_value (0.0, PHOTOS_ZOOM_EVENT_TOUCH);
-  g_assert_true (g_variant_is_floating (parameter));
-
   g_action_activate (self->zoom_begin_action, parameter);
 }
 
@@ -291,8 +285,6 @@ photos_preview_view_gesture_zoom_end (PhotosPreviewView *self)
   GVariant *parameter;
 
   parameter = photos_utils_create_zoom_target_value (0.0, PHOTOS_ZOOM_EVENT_TOUCH);
-  g_assert_true (g_variant_is_floating (parameter));
-
   g_action_activate (self->zoom_end_action, parameter);
 }
 
@@ -305,7 +297,6 @@ photos_preview_view_gesture_zoom_scale_changed (PhotosPreviewView *self,
   GVariant *parameter;
 
   parameter = photos_utils_create_zoom_target_value (scale, PHOTOS_ZOOM_EVENT_TOUCH);
-  g_assert_true (g_variant_is_floating (parameter));
 
   switch (direction)
     {
@@ -606,13 +597,34 @@ photos_preview_view_blacks_exposure (PhotosPreviewView *self, GVariant *paramete
 
 
 static void
-photos_preview_view_brightness_contrast (PhotosPreviewView *self, GVariant *parameter)
+photos_preview_view_contrast (PhotosPreviewView *self, GVariant *parameter)
+{
+  PhotosBaseItem *item;
+  gdouble contrast;
+
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (self->item_mngr));
+  if (item == NULL)
+    return;
+
+  contrast = g_variant_get_double (parameter);
+  photos_base_item_operation_add_async (item,
+                                        self->cancellable,
+                                        photos_preview_view_process,
+                                        self,
+                                        "gegl:brightness-contrast",
+                                        "contrast", contrast,
+                                        NULL);
+}
+
+
+static void
+photos_preview_view_shadows_highlights (PhotosPreviewView *self, GVariant *parameter)
 {
   GVariantIter iter;
   PhotosBaseItem *item;
   const gchar *key;
-  gdouble brightness = -G_MAXDOUBLE;
-  gdouble contrast = -G_MAXDOUBLE;
+  gdouble shadows = -G_MAXDOUBLE;
+  gdouble highlights = -G_MAXDOUBLE;
   gdouble value;
 
   item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (self->item_mngr));
@@ -622,22 +634,22 @@ photos_preview_view_brightness_contrast (PhotosPreviewView *self, GVariant *para
   g_variant_iter_init (&iter, parameter);
   while (g_variant_iter_next (&iter, "{&sd}", &key, &value))
     {
-      if (g_strcmp0 (key, "brightness") == 0)
-        brightness = value;
-      else if (g_strcmp0 (key, "contrast") == 0)
-        contrast = value;
+      if (g_strcmp0 (key, "shadows") == 0)
+        shadows = value;
+      else if (g_strcmp0 (key, "highlights") == 0)
+        highlights = value;
     }
 
-  g_return_if_fail (brightness > -G_MAXDOUBLE);
-  g_return_if_fail (contrast > -G_MAXDOUBLE);
+  g_return_if_fail (shadows > -G_MAXDOUBLE);
+  g_return_if_fail (highlights > -G_MAXDOUBLE);
 
   photos_base_item_operation_add_async (item,
                                         self->cancellable,
                                         photos_preview_view_process,
                                         self,
-                                        "gegl:brightness-contrast",
-                                        "brightness", brightness,
-                                        "contrast", contrast,
+                                        "photos:shadows-highlights",
+                                        "shadows", shadows,
+                                        "highlights", highlights,
                                         NULL);
 }
 
@@ -1308,10 +1320,10 @@ photos_preview_view_init (PhotosPreviewView *self)
                            self,
                            G_CONNECT_SWAPPED);
 
-  action = g_action_map_lookup_action (G_ACTION_MAP (app), "brightness-contrast-current");
+  action = g_action_map_lookup_action (G_ACTION_MAP (app), "contrast-current");
   g_signal_connect_object (action,
                            "activate",
-                           G_CALLBACK (photos_preview_view_brightness_contrast),
+                           G_CALLBACK (photos_preview_view_contrast),
                            self,
                            G_CONNECT_SWAPPED);
 
@@ -1334,6 +1346,13 @@ photos_preview_view_init (PhotosPreviewView *self)
                            self,
                            G_CONNECT_SWAPPED);
 
+  action = g_action_map_lookup_action (G_ACTION_MAP (app), "shadows-highlights-current");
+  g_signal_connect_object (action,
+                           "activate",
+                           G_CALLBACK (photos_preview_view_shadows_highlights),
+                           self,
+                           G_CONNECT_SWAPPED);
+
   action = g_action_map_lookup_action (G_ACTION_MAP (app), "sharpen-current");
   g_signal_connect_object (action, "activate", G_CALLBACK (photos_preview_view_sharpen), self, G_CONNECT_SWAPPED);
 
