@@ -50,11 +50,6 @@ struct _PhotosSetCollectionJob
   gpointer user_data;
 };
 
-struct _PhotosSetCollectionJobClass
-{
-  GObjectClass parent_class;
-};
-
 enum
 {
   PROP_0,
@@ -239,7 +234,7 @@ photos_set_collection_job_run (PhotosSetCollectionJob *self,
   urns = photos_selection_controller_get_selection (self->sel_cntrlr);
   for (l = urns; l != NULL; l = l->next)
     {
-      PhotosQuery *query;
+      PhotosQuery *query = NULL;
       const gchar *urn = (gchar *) l->data;
 
       if (g_strcmp0 (self->collection_urn, urn) == 0)
@@ -248,11 +243,11 @@ photos_set_collection_job_run (PhotosSetCollectionJob *self,
       self->running_jobs++;
       query = photos_query_builder_set_collection_query (state, urn, self->collection_urn, self->setting);
       photos_tracker_queue_update (self->queue,
-                                   query->sparql,
+                                   query,
                                    NULL,
                                    photos_set_collection_job_query_executed,
                                    g_object_ref (self),
                                    g_object_unref);
-      photos_query_free (query);
+      g_object_unref (query);
     }
 }
