@@ -29,31 +29,7 @@
 G_BEGIN_DECLS
 
 #define PHOTOS_TYPE_SHARE_DIALOG (photos_share_dialog_get_type ())
-
-#define PHOTOS_SHARE_DIALOG(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-   PHOTOS_TYPE_SHARE_DIALOG, PhotosShareDialog))
-
-#define PHOTOS_SHARE_DIALOG_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST ((klass), \
-   PHOTOS_TYPE_SHARE_DIALOG, PhotosShareDialogClass))
-
-#define PHOTOS_IS_SHARE_DIALOG(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
-   PHOTOS_TYPE_SHARE_DIALOG))
-
-#define PHOTOS_IS_SHARE_DIALOG_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE ((klass), \
-   PHOTOS_TYPE_SHARE_DIALOG))
-
-#define PHOTOS_SHARE_DIALOG_GET_CLASS(obj) \
-  (G_TYPE_INSTANCE_GET_CLASS ((obj), \
-   PHOTOS_TYPE_SHARE_DIALOG, PhotosShareDialogClass))
-
-typedef struct _PhotosShareDialog      PhotosShareDialog;
-typedef struct _PhotosShareDialogClass PhotosShareDialogClass;
-
-GType               photos_share_dialog_get_type                 (void) G_GNUC_CONST;
+G_DECLARE_FINAL_TYPE (PhotosShareDialog, photos_share_dialog, PHOTOS, SHARE_DIALOG, GtkDialog);
 
 GtkWidget          *photos_share_dialog_new                      (GtkWindow *parent, PhotosBaseItem *item);
 
