@@ -29,6 +29,8 @@
 #include <tracker-sparql.h>
 
 #include "photos-debug.h"
+#include "photos-filterable.h"
+#include "photos-source.h"
 #include "photos-tracker-queue.h"
 
 
@@ -63,8 +65,8 @@ struct _PhotosTrackerQueueData
   GAsyncReadyCallback callback;
   GCancellable *cancellable;
   GDestroyNotify destroy_data;
+  PhotosQuery *query;
   PhotosTrackerQueryType query_type;
-  gchar *sparql;
   gpointer user_data;
 };
 
@@ -78,8 +80,8 @@ static void photos_tracker_queue_check (PhotosTrackerQueue *self);
 static void
 photos_tracker_queue_data_free (PhotosTrackerQueueData *data)
 {
+  g_clear_object (&data->query);
   g_clear_object (&data->cancellable);
-  g_free (data->sparql);
 
   if (data->destroy_data != NULL)
     (*data->destroy_data) (data->user_data);
@@ -89,7 +91,7 @@ photos_tracker_queue_data_free (PhotosTrackerQueueData *data)
 
 
 static PhotosTrackerQueueData *
-photos_tracker_queue_data_new (const gchar *sparql,
+photos_tracker_queue_data_new (PhotosQuery *query,
                                PhotosTrackerQueryType query_type,
                                GCancellable *cancellable,
                                GAsyncReadyCallback callback,
@@ -99,7 +101,8 @@ photos_tracker_queue_data_new (const gchar *sparql,
   PhotosTrackerQueueData *data;
 
   data = g_slice_new0 (PhotosTrackerQueueData);
-  data->sparql = g_strdup (sparql);
+
+  data->query = g_object_ref (query);
   data->query_type = query_type;
   data->cancellable = cancellable;
   data->callback = callback;
@@ -110,6 +113,33 @@ photos_tracker_queue_data_new (const gchar *sparql,
 }
 
 
+static void
+photos_tracker_queue_log_query (PhotosQuery *query)
+{
+  PhotosSource *source;
+  const gchar *sparql;
+  const gchar *tag;
+
+  tag = photos_query_get_tag (query);
+  if (tag != NULL && tag[0] != '\0')
+    photos_debug (PHOTOS_DEBUG_TRACKER, "%s", tag);
+
+  source = photos_query_get_source (query);
+  if (source != NULL)
+    {
+      const gchar *id;
+      const gchar *name;
+
+      id = photos_filterable_get_id (PHOTOS_FILTERABLE (source));
+      name = photos_source_get_name (source);
+      photos_debug (PHOTOS_DEBUG_TRACKER, "Source (%s): %s", id, name);
+    }
+
+  sparql = photos_query_get_sparql (query);
+  photos_debug (PHOTOS_DEBUG_TRACKER, "%s", sparql);
+}
+
+
 static void
 photos_tracker_queue_collector (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
@@ -131,6 +161,7 @@ static void
 photos_tracker_queue_check (PhotosTrackerQueue *self)
 {
   PhotosTrackerQueueData *data;
+  const gchar *sparql;
 
   if (self->running)
     return;
@@ -141,13 +172,14 @@ photos_tracker_queue_check (PhotosTrackerQueue *self)
   data = g_queue_peek_head (self->queue);
   self->running = TRUE;
 
-  photos_debug (PHOTOS_DEBUG_TRACKER, "%s", data->sparql);
+  photos_tracker_queue_log_query (data->query);
+  sparql = photos_query_get_sparql (data->query);
 
   switch (data->query_type)
     {
     case PHOTOS_TRACKER_QUERY_SELECT:
       tracker_sparql_connection_query_async (self->connection,
-                                             data->sparql,
+                                             sparql,
                                              data->cancellable,
                                              photos_tracker_queue_collector,
                                              g_object_ref (self));
@@ -155,7 +187,7 @@ photos_tracker_queue_check (PhotosTrackerQueue *self)
 
     case PHOTOS_TRACKER_QUERY_UPDATE:
       tracker_sparql_connection_update_async (self->connection,
-                                              data->sparql,
+                                              sparql,
                                               G_PRIORITY_DEFAULT,
                                               data->cancellable,
                                               photos_tracker_queue_collector,
@@ -164,7 +196,7 @@ photos_tracker_queue_check (PhotosTrackerQueue *self)
 
     case PHOTOS_TRACKER_QUERY_UPDATE_BLANK:
       tracker_sparql_connection_update_blank_async (self->connection,
-                                                    data->sparql,
+                                                    sparql,
                                                     G_PRIORITY_DEFAULT,
                                                     data->cancellable,
                                                     photos_tracker_queue_collector,
@@ -295,7 +327,7 @@ photos_tracker_queue_dup_singleton (GCancellable *cancellable, GError **error)
 
 void
 photos_tracker_queue_select (PhotosTrackerQueue *self,
-                             const gchar *sparql,
+                             PhotosQuery *query,
                              GCancellable *cancellable,
                              GAsyncReadyCallback callback,
                              gpointer user_data,
@@ -306,7 +338,7 @@ photos_tracker_queue_select (PhotosTrackerQueue *self,
   if (cancellable != NULL)
     g_object_ref (cancellable);
 
-  data = photos_tracker_queue_data_new (sparql,
+  data = photos_tracker_queue_data_new (query,
                                         PHOTOS_TRACKER_QUERY_SELECT,
                                         cancellable,
                                         callback,
@@ -320,7 +352,7 @@ photos_tracker_queue_select (PhotosTrackerQueue *self,
 
 void
 photos_tracker_queue_update (PhotosTrackerQueue *self,
-                             const gchar *sparql,
+                             PhotosQuery *query,
                              GCancellable *cancellable,
                              GAsyncReadyCallback callback,
                              gpointer user_data,
@@ -331,7 +363,7 @@ photos_tracker_queue_update (PhotosTrackerQueue *self,
   if (cancellable != NULL)
     g_object_ref (cancellable);
 
-  data = photos_tracker_queue_data_new (sparql,
+  data = photos_tracker_queue_data_new (query,
                                         PHOTOS_TRACKER_QUERY_UPDATE,
                                         cancellable,
                                         callback,
@@ -345,7 +377,7 @@ photos_tracker_queue_update (PhotosTrackerQueue *self,
 
 void
 photos_tracker_queue_update_blank (PhotosTrackerQueue *self,
-                                   const gchar *sparql,
+                                   PhotosQuery *query,
                                    GCancellable *cancellable,
                                    GAsyncReadyCallback callback,
                                    gpointer user_data,
@@ -356,7 +388,7 @@ photos_tracker_queue_update_blank (PhotosTrackerQueue *self,
   if (cancellable != NULL)
     g_object_ref (cancellable);
 
-  data = photos_tracker_queue_data_new (sparql,
+  data = photos_tracker_queue_data_new (query,
                                         PHOTOS_TRACKER_QUERY_UPDATE_BLANK,
                                         cancellable,
                                         callback,
