@@ -426,6 +426,7 @@ photos_utils_create_zoom_target_value (gdouble delta, PhotosZoomEvent event)
   ret_val = g_variant_builder_end (&builder);
 
   g_type_class_unref (zoom_event_class);
+  g_return_val_if_fail (g_variant_is_floating (ret_val), ret_val);
   return ret_val;
 }
 
@@ -456,6 +457,9 @@ photos_utils_get_thumbnail_icon (const gchar *uri)
     }
 
   thumb_path = g_file_info_get_attribute_byte_string (info, G_FILE_ATTRIBUTE_THUMBNAIL_PATH);
+  if (thumb_path == NULL)
+    goto out;
+
   thumb_file = g_file_new_for_path (thumb_path);
   icon = g_file_icon_new (thumb_file);
 
@@ -1308,7 +1312,7 @@ photos_utils_list_box_header_func (GtkListBoxRow *row, GtkListBoxRow *before, gp
 void
 photos_utils_object_list_free_full (GList *objects)
 {
-  g_list_free_full (objects, (GDestroyNotify) g_object_unref);
+  g_list_free_full (objects, g_object_unref);
 }
 
 
